@@ -15,14 +15,24 @@ class browser:
     driver = ""
     wait_timeout = 30
 
-    def create(self, page_load_timeout, wait_timeout, add_log = True):
+    def create_firefox(self, page_load_timeout, wait_timeout, add_log = True):
+        self.create_browser(page_load_timeout, wait_timeout, False, add_log)
+
+    def create_chrome(self, page_load_timeout, wait_timeout, add_log = True):
+        self.create_browser(page_load_timeout, wait_timeout, True, add_log)
+
+    def create_browser(self, page_load_timeout, wait_timeout, chrome, add_log = True):
         if not sys.platform == 'win32':
             self.add_and_print_log('Creating display', add_log)
             self.display = Display(visible=0, size=(1920, 768))
             self.display.start()
-
         self.add_and_print_log('Creating browser', add_log)
-        self.driver = webdriver.Firefox()
+
+        if (chrome):
+            self.driver = webdriver.Chrome()
+        else:
+            self.driver = webdriver.Firefox()
+
         self.driver.set_page_load_timeout(page_load_timeout)
         self.wait_timeout = wait_timeout
 
